======
Thanks
======


.. image:: https://img.shields.io/pypi/v/thanks.svg
        :target: https://pypi.python.org/pypi/thanks

.. image:: https://img.shields.io/travis/phildini/thanks.svg
        :target: https://travis-ci.org/phildini/thanks

.. image:: https://readthedocs.org/projects/thanks/badge/?version=latest
        :target: https://thanks.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Finding ways to fund the python packages you use. Inspired by `feross' thanks`_

Run `thanks` on your requirements.txt to find ways to support the developers
who are supporting your code. 💚

.. code-block:: bash
$ pip install thanks
$ thanks requirements.txt


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _feross' thanks: https://github.com/feross/thanks
